@@ -2,9 +2,8 @@
 
 
 import click
-from cligj import format_opt
 
-import rasterio
+from rasterio.enums import Resampling
 from rasterio.rio import options
 from rasterio.rio.helpers import resolve_inout
 
@@ -12,19 +11,26 @@ from rasterio.rio.helpers import resolve_inout
 @click.command(short_help="Merge a stack of raster datasets.")
 @options.files_inout_arg
 @options.output_opt
-@format_opt
+@options.format_opt
 @options.bounds_opt
 @options.resolution_opt
+@click.option('--resampling',
+              type=click.Choice([r.name for r in Resampling if r.value <= 7]),
+              default='nearest', help="Resampling method.",
+              show_default=True)
 @options.nodata_opt
 @options.bidx_mult_opt
 @options.overwrite_opt
-@click.option('--precision', type=int, default=10,
-              help="Number of decimal places of precision in alignment of "
-                   "pixels")
+@click.option(
+    "--precision",
+    type=int,
+    default=None,
+    help="Number of decimal places of precision in alignment of pixels",
+)
 @options.creation_options
 @click.pass_context
-def merge(ctx, files, output, driver, bounds, res, nodata, bidx, overwrite,
-          precision, creation_options):
+def merge(ctx, files, output, driver, bounds, res, resampling,
+          nodata, bidx, overwrite, precision, creation_options):
     """Copy valid pixels from input files to an output file.
 
     All files must have the same number of bands, data type, and
@@ -49,35 +55,17 @@ def merge(ctx, files, output, driver, bounds, res, nodata, bidx, overwrite,
     output, files = resolve_inout(
         files=files, output=output, overwrite=overwrite)
 
+    resampling = Resampling[resampling]
+
     with ctx.obj["env"]:
-        dest, output_transform = merge_tool(
+        merge_tool(
             files,
             bounds=bounds,
             res=res,
             nodata=nodata,
             precision=precision,
             indexes=(bidx or None),
+            resampling=resampling,
+            dst_path=output,
+            dst_kwds=creation_options,
         )
-
-        with rasterio.open(files[0]) as first:
-            profile = first.profile
-            profile["transform"] = output_transform
-            profile["height"] = dest.shape[1]
-            profile["width"] = dest.shape[2]
-            profile["driver"] = driver
-            profile["count"] = dest.shape[0]
-
-            if nodata is not None:
-                profile["nodata"] = nodata
-
-            profile.update(**creation_options)
-
-            with rasterio.open(output, "w", **profile) as dst:
-                dst.write(dest)
-
-                # uses the colormap in the first input raster.
-                try:
-                    colormap = first.colormap(1)
-                    dst.write_colormap(1, colormap)
-                except ValueError:
-                    pass
